@@ -17,7 +17,6 @@ from typing import (
     AbstractSet,
     Any,
     Callable,
-    ClassVar,
     Dict,
     Iterable,
     Iterator,
@@ -30,7 +29,7 @@ from typing import (
     cast,
 )
 
-from robotcode.language_server.common.lsp_types import Position, Range
+from robotcode.core.lsp.types import Position, Range
 from robotcode.language_server.robotframework.utils.ast_utils import (
     Token,
     range_from_token,
@@ -196,7 +195,7 @@ class KeywordMatcher:
         return self.name
 
     def __repr__(self) -> str:
-        return f"{type(self).__name__}(name={repr(self.name)})"
+        return f"{type(self).__name__}(name={self.name!r})"
 
 
 RUN_KEYWORD_WITH_CONDITION_MATCHERS = [KeywordMatcher(e) for e in RUN_KEYWORD_WITH_CONDITION_NAMES]
@@ -311,7 +310,7 @@ class ArgumentSpec:
                 self.defaults,
                 self.types,
             )
-
+        self.__robot_arguments.name = self.name
         resolver = ArgumentResolver(
             self.__robot_arguments,
             resolve_named=resolve_named,
@@ -457,9 +456,9 @@ class KeywordDoc(SourceEntity):
                     prefix = "**"
 
                 result += (
-                    f"\n| `{prefix}{str(a.name)}`"
+                    f"\n| `{prefix}{a.name!s}`"
                     f"| {'=' if a.default_value is not None else ''}"
-                    f"| {f'`{str(a.default_value)}`' if a.default_value else ''}"
+                    f"| {f'`{a.default_value!s}`' if a.default_value else ''}"
                     f"| {' or '.join(f'`<{s}>`' for s in a.types) if a.types is not None else ''} |"
                 )
 
@@ -615,6 +614,9 @@ class LibraryType(Enum):
 
 ROBOT_DEFAULT_SCOPE = "TEST"
 
+RE_INLINE_LINK = re.compile(r"([\`])((?:\1|.)+?)\1", re.VERBOSE)
+RE_HEADERS = re.compile(r"^(#{2,9})\s+(\S.*)$", re.MULTILINE)
+
 
 @dataclass
 class LibraryDoc:
@@ -747,22 +749,15 @@ class LibraryDoc:
 
         return None
 
-    _inline_link: ClassVar[re.Pattern] = re.compile(  # type: ignore
-        r"([\`])((?:\1|.)+?)\1",
-        re.VERBOSE,
-    )
-
-    _headers: ClassVar[re.Pattern] = re.compile(r"^(#{2,9})\s+(\S.*)$", re.MULTILINE)  # type: ignore
-
     def _link_inline_links(self, text: str) -> str:
-        headers = [v.group(2) for v in self._headers.finditer(text)]
+        headers = [v.group(2) for v in RE_HEADERS.finditer(text)]
 
         def repl(m: re.Match) -> str:  # type: ignore
             if m.group(2) in headers:
-                return f"[{str(m.group(2))}](\\#{str(m.group(2)).lower().replace(' ', '-')})"
+                return f"[{m.group(2)!s}](\\#{str(m.group(2)).lower().replace(' ', '-')})"
             return str(m.group(0))
 
-        return str(self._inline_link.sub(repl, text))
+        return str(RE_INLINE_LINK.sub(repl, text))
 
     def _get_doc_for_keywords(self, header_level: int = 2) -> str:
         result = ""
@@ -1063,7 +1058,7 @@ def resolve_robot_variables(
 
     if command_line_variables:
         for k1, v1 in command_line_variables.items():
-            result[f"${{{k1}}}"] = v1
+            result[k1] = v1
 
     if variables is not None:
         vars = [_Variable(k, v) for k, v in variables.items() if v is not None and not isinstance(v, NativeValue)]
@@ -1517,7 +1512,9 @@ def get_variables_doc(
     command_line_variables: Optional[Dict[str, Optional[Any]]] = None,
     variables: Optional[Dict[str, Optional[Any]]] = None,
 ) -> VariablesDoc:
+    from robot.libdocpkg.robotbuilder import KeywordDocBuilder
     from robot.output import LOGGER
+    from robot.running.handlers import _PythonHandler
     from robot.utils.importer import Importer
     from robot.variables.filesetter import PythonImporter, YamlImporter
 
@@ -1528,6 +1525,7 @@ def get_variables_doc(
     try:
         with _std_capture() as std_capturer:
             import_name = find_variables(name, working_dir, base_dir, command_line_variables, variables)
+            get_variables = None
 
             if import_name.lower().endswith((".yaml", ".yml")):
                 source = import_name
@@ -1548,6 +1546,9 @@ def get_variables_doc(
                     def import_variables(self, path: str, args: Optional[Tuple[Any, ...]] = None) -> Any:
                         return self._get_variables(self.var_file, args)
 
+                    def is_dynamic(self) -> bool:
+                        return bool(self._is_dynamic(self.var_file))
+
                 module_importer = Importer("variable file", LOGGER)
 
                 if get_robot_version() >= (5, 0):
@@ -1560,6 +1561,9 @@ def get_variables_doc(
 
                 importer = MyPythonImporter(libcode)
 
+                if importer.is_dynamic():
+                    get_variables = getattr(libcode, "get_variables", None) or getattr(libcode, "getVariables", None)
+
             # TODO: add type information of the value including dict key names and member names
             vars: List[ImportedVariableDefinition] = [
                 ImportedVariableDefinition(
@@ -1577,7 +1581,7 @@ def get_variables_doc(
                 for name, value in importer.import_variables(import_name, args)
             ]
 
-            return VariablesDoc(
+            libdoc = VariablesDoc(
                 name=stem,
                 source=source or module_spec.origin if module_spec is not None else import_name,
                 module_spec=module_spec,
@@ -1585,6 +1589,46 @@ def get_variables_doc(
                 stdout=std_capturer.getvalue(),
                 python_path=sys.path,
             )
+
+            if get_variables is not None:
+
+                class VarHandler(_PythonHandler):
+                    def _get_name(self, handler_name: Any, handler_method: Any) -> Any:
+                        return get_variables.__name__ if get_variables is not None else ""
+
+                    def _get_initial_handler(self, library: Any, name: Any, method: Any) -> Any:
+                        return None
+
+                vars_initializer = VarHandler(libdoc, get_variables.__name__, get_variables)
+
+                libdoc.inits = KeywordStore(
+                    keywords=[
+                        KeywordDoc(
+                            name=libdoc.name,
+                            args=[KeywordArgumentDoc.from_robot(a) for a in kw[0].args],
+                            doc=kw[0].doc,
+                            tags=list(kw[0].tags),
+                            source=kw[0].source,
+                            line_no=kw[0].lineno if kw[0].lineno is not None else -1,
+                            col_offset=-1,
+                            end_col_offset=-1,
+                            end_line_no=-1,
+                            type="library",
+                            libname=libdoc.name,
+                            libtype=libdoc.type,
+                            longname=f"{libdoc.name}.{kw[0].name}",
+                            is_initializer=True,
+                            arguments=ArgumentSpec.from_robot_argument_spec(kw[1].arguments),
+                            parent=libdoc.digest,
+                        )
+                        for kw in [
+                            (KeywordDocBuilder().build_keyword(k), k)
+                            for k in [KeywordWrapper(vars_initializer, libdoc.source or "")]
+                        ]
+                    ]
+                )
+
+            return libdoc
     except (SystemExit, KeyboardInterrupt, IgnoreEasterEggLibraryWarning):
         raise
     except BaseException as e:
